# Generated by roxygen2: do not edit by hand

S3method(coef,mvfmr)
S3method(coef,mvfmr_separate)
S3method(plot,mvfmr)
S3method(plot,mvfmr_separate)
S3method(print,mvfmr)
S3method(print,mvfmr_separate)
S3method(summary,mvfmr)
S3method(summary,mvfmr_separate)
S3method(vcov,mvfmr)
S3method(vcov,mvfmr_separate)
export(IS)
export(cf_logit)
export(fmvmr_separate_twosample)
export(fmvmr_twosample)
export(getX_multi_exposure)
export(getX_multi_exposure_mediation)
export(getY_multi_exposure)
export(gmm_lm_onesample)
export(gmm_twosample_simple)
export(mvfmr)
export(mvfmr_separate)
import(fdapace)
import(ggplot2)
importFrom(doParallel,registerDoParallel)
importFrom(foreach,"%dopar%")
importFrom(foreach,foreach)
importFrom(glmnet,cv.glmnet)
importFrom(gridExtra,grid.arrange)
importFrom(pROC,auc)
importFrom(pROC,roc)
importFrom(parallel,detectCores)
importFrom(parallel,makeCluster)
importFrom(parallel,stopCluster)
importFrom(progress,progress_bar)
importFrom(stats,coef)
importFrom(stats,fitted)
importFrom(stats,lm)
importFrom(stats,na.omit)
importFrom(stats,nlminb)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,spline)
importFrom(stats,time)
importFrom(stats,var)
importFrom(stats,vcov)
